#
# spec file for package libmnl
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname	%{name}0
Name:           libmnl
Version:        1.0.5
Release:        1.7
Summary:        Minimalistic Netlink communication library
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Security
URL:            https://netfilter.org/projects/libmnl/
#Git-Clone:	git://git.netfilter.org/libmnl
Source:         https://www.netfilter.org/projects/libmnl/files/libmnl-%version.tar.bz2
Source2:        https://www.netfilter.org/projects/libmnl/files/libmnl-%version.tar.bz2.sig
Source3:        %name.keyring
Source9:        baselibs.conf
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.21

%description
libmnl is a minimalistic user-space library oriented to Netlink
developers. There are a lot of common tasks in parsing, validating,
constructing of both the Netlink header and TLVs that are repetitive
and easy to get wrong. This library aims to provide simple helpers
that allows you to re-use code and to avoid re-inventing the wheel.

%package -n %lname
Summary:        Minimalistic Netlink communication library
Group:          System/Libraries

%description -n %lname
libmnl is a minimalistic user-space library oriented to Netlink
developers. There are a lot of common tasks in parsing, validating,
constructing of both the Netlink header and TLVs that are repetitive
and easy to get wrong. This library aims to provide simple helpers
that allows you to re-use code and to avoid re-inventing the wheel.

%package devel
Summary:        Development files for libmnl
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libmnl is a minimalistic user-space library oriented to Netlink
developers. There are a lot of common tasks in parsing, validating,
constructing of both the Netlink header and TLVs that are repetitive
and easy to get wrong. This library aims to provide simple helpers
that allows you to re-use code and to avoid re-inventing the wheel.

%prep
%setup -q

%build
# includedir intentional, cf. bugzilla.opensuse.org/795968
%configure --includedir="%_includedir/%name"
%make_build

%check
%make_build check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING
%_libdir/libmnl.so.*

%files devel
%license COPYING
%doc README
%_includedir/%name/
%_libdir/libmnl.so
%_libdir/pkgconfig/libmnl.pc

%changelog
* Tue Apr  5 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.5
  * New example program
  * "MNL_SOCKET_DUMP_SIZE" define, holding a recommended buffer
    size for netlink dumps.
  * Resolved compiler warnings
* Thu Apr 16 2020 Andreas Stieger <andreas.stieger@gmx.de>
- package the license text
* Sat Jul  2 2016 jengelh@inai.de
- Update to new upstream release 1.0.4
  * Improvements in the netlink message printing function,
  attribute validation for MNL_TYPE_MSEC and MNL_TYPE_U64, clang
  compilation fixes, the new mnl_socket_open2() and
  mnl_socket_fdopen() functions, missing handling for
  NLM_F_DUMP_INTR and documentation updates.
* Tue Dec  9 2014 jengelh@inai.de
- Remove extra directory pkg, one level is enough.
* Tue Sep 23 2014 jengelh@inai.de
- Move include files to /usr/include/pkg, like done in many other
  packages
* Thu Apr 24 2014 dmueller@suse.com
- remove dependency on gpg-offline, source validator already
  does that
* Wed Nov 28 2012 sbrabec@suse.cz
- Verify GPG signature
* Sat May 26 2012 jengelh@inai.de
- Update to new upstream release 1.0.3
  * Added the "mnl_attr_for_each_payload" function, which allows to
  iterate over attributes for a given payload pointer.
* Mon Jan  2 2012 jengelh@medozas.de
- Update to new upstream release 1.0.2
  * build and compile updates
  * header: fix invalid use of type void * in arithmetic of
  mnl_for_each_nest(...)
  * doc: fix wrong comment describing mnl_nlmsg_batch_stop
* Thu Dec 29 2011 jengelh@medozas.de
- SPDX format for License: tag
- Use separate include dir to detect compile errors
* Sun Dec 26 2010 jengelh@medozas.de
- Update to libmnl 1.0.1
  * examples: fix wrong group mask number in nfct-event
  * header: fix signess issues in MNL_SOCKET_BUFFER_SIZE
* Fri Dec 17 2010 jengelh@medozas.de
- Update to initial public tarball release, version 1.0.0
  * Added checking variants of the put function family.
  * Message batching infrastructure
- Run spec-beautifier on .spec file
* Tue Oct 19 2010 jengelh@medozas.de
- Initial package
